==> jc-1.4.0.tar.gz: java/awt/dnd/DragSourceDropEvent.h <==
// public class java.awt.dnd.DragSourceDropEvent

// class file dependencies
// @dep_class bb24d33bd85e9fb2 java_awt_dnd_DragSourceDropEvent
// @dep_class 8fa38a35dead9728 java_awt_dnd_DragSourceEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_dnd_DragSourceEvent

#include "java/awt/dnd/DragSourceEvent.h"

#ifndef _JC_java_awt_dnd_DragSourceDropEvent_H_
#define _JC_java_awt_dnd_DragSourceDropEvent_H_

// Forward structure declarations
struct _jc_java_awt_dnd_DragSourceContext$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DragSourceDropEvent$sub_refs	_jc_java_awt_dnd_DragSourceDropEvent$sub_refs;
typedef struct _jc_java_awt_dnd_DragSourceDropEvent$sub_nonrefs	_jc_java_awt_dnd_DragSourceDropEvent$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DragSourceDropEvent$refs	_jc_java_awt_dnd_DragSourceDropEvent$refs;
typedef struct _jc_java_awt_dnd_DragSourceDropEvent$nonrefs	_jc_java_awt_dnd_DragSourceDropEvent$nonrefs;
typedef struct _jc_java_awt_dnd_DragSourceDropEvent$object	_jc_java_awt_dnd_DragSourceDropEvent$object;

typedef struct _jc_java_awt_dnd_DragSourceDropEvent$fields_struct	_jc_java_awt_dnd_DragSourceDropEvent$fields_struct;
typedef const struct _jc_java_awt_dnd_DragSourceDropEvent$vmethods	_jc_java_awt_dnd_DragSourceDropEvent$vmethods;
typedef const struct _jc_java_awt_dnd_DragSourceDropEvent$vtable	_jc_java_awt_dnd_DragSourceDropEvent$vtable;
typedef const struct _jc_java_awt_dnd_DragSourceDropEvent$vtype	_jc_java_awt_dnd_DragSourceDropEvent$vtype;

// Class fields structure
struct _jc_java_awt_dnd_DragSourceDropEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_dnd_DragSourceDropEvent$fields_struct _jc_java_awt_dnd_DragSourceDropEvent$class_fields;

// Constructors
extern void _jc_java_awt_dnd_DragSourceDropEvent$method$_init$64d9ad50fc3f446f(_jc_env *, struct _jc_java_awt_dnd_DragSourceDropEvent$object *, struct _jc_java_awt_dnd_DragSourceContext$object *);
extern void _jc_java_awt_dnd_DragSourceDropEvent$method$_init$1116487a21365ea1(_jc_env *, struct _jc_java_awt_dnd_DragSourceDropEvent$object *, struct _jc_java_awt_dnd_DragSourceContext$object *, jint, jboolean);
extern void _jc_java_awt_dnd_DragSourceDropEvent$method$_init$f32e111d49289dbc(_jc_env *, struct _jc_java_awt_dnd_DragSourceDropEvent$object *, struct _jc_java_awt_dnd_DragSourceContext$object *, jint, jboolean, jint, jint);

// Virtual methods
extern jint _jc_java_awt_dnd_DragSourceDropEvent$method$getDropAction$edda4aeecf125b6a(_jc_env *, struct _jc_java_awt_dnd_DragSourceDropEvent$object *);
extern jboolean _jc_java_awt_dnd_DragSourceDropEvent$method$getDropSuccess$dfbe197d0d99e605(_jc_env *, struct _jc_java_awt_dnd_DragSourceDropEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DragSourceDropEvent$method_info$getDropAction$edda4aeecf125b6a;
extern _jc_method _jc_java_awt_dnd_DragSourceDropEvent$method_info$getDropSuccess$dfbe197d0d99e605;

// Virtual methods structure
struct _jc_java_awt_dnd_DragSourceDropEvent$vmethods {
	jint	(*getDropAction$edda4aeecf125b6a)(_jc_env *, struct _jc_java_awt_dnd_DragSourceDropEvent$object *);
	jboolean	(*getDropSuccess$dfbe197d0d99e605)(_jc_env *, struct _jc_java_awt_dnd_DragSourceDropEvent$object *);
};

// Vtable
struct _jc_java_awt_dnd_DragSourceDropEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_dnd_DragSourceEvent$vmethods	java_awt_dnd_DragSourceEvent;
	_jc_java_awt_dnd_DragSourceDropEvent$vmethods	java_awt_dnd_DragSourceDropEvent;
};

// Vtype
struct _jc_java_awt_dnd_DragSourceDropEvent$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DragSourceDropEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DragSourceDropEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DragSourceDropEvent$refs {
    _jc_java_awt_dnd_DragSourceDropEvent$sub_refs	java_awt_dnd_DragSourceDropEvent;
    _jc_java_awt_dnd_DragSourceEvent$sub_refs	java_awt_dnd_DragSourceEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DragSourceDropEvent$sub_nonrefs {
	jint	dropAction;
	jboolean	dropSuccess;
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DragSourceDropEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_dnd_DragSourceEvent$sub_nonrefs	java_awt_dnd_DragSourceEvent;
    _jc_java_awt_dnd_DragSourceDropEvent$sub_nonrefs	java_awt_dnd_DragSourceDropEvent;
};

// Object instance structure
struct _jc_java_awt_dnd_DragSourceDropEvent$object {
	_jc_java_awt_dnd_DragSourceDropEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DragSourceDropEvent$vtype	*vtype;
	_jc_java_awt_dnd_DragSourceDropEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DragSourceDropEvent$vtype _jc_java_awt_dnd_DragSourceDropEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DragSourceDropEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DragSourceDropEvent$class_object;

#endif	/* _JC_java_awt_dnd_DragSourceDropEvent_H_ */

==> jc-1.4.6.tar.gz: java/awt/dnd/DragSourceDropEvent.h <==
// public class java.awt.dnd.DragSourceDropEvent

// class file dependencies
// @dep_class bb24d33bd85e9fb2 java_awt_dnd_DragSourceDropEvent
// @dep_class 8fa38a35dead9728 java_awt_dnd_DragSourceEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_dnd_DragSourceEvent

#include "java/awt/dnd/DragSourceEvent.h"

#ifndef _JC_java_awt_dnd_DragSourceDropEvent_H_
#define _JC_java_awt_dnd_DragSourceDropEvent_H_

// Forward structure declarations
struct _jc_java_awt_dnd_DragSourceContext$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DragSourceDropEvent$sub_refs	_jc_java_awt_dnd_DragSourceDropEvent$sub_refs;
typedef struct _jc_java_awt_dnd_DragSourceDropEvent$sub_nonrefs	_jc_java_awt_dnd_DragSourceDropEvent$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DragSourceDropEvent$refs	_jc_java_awt_dnd_DragSourceDropEvent$refs;
typedef struct _jc_java_awt_dnd_DragSourceDropEvent$nonrefs	_jc_java_awt_dnd_DragSourceDropEvent$nonrefs;
typedef struct _jc_java_awt_dnd_DragSourceDropEvent$object	_jc_java_awt_dnd_DragSourceDropEvent$object;

typedef struct _jc_java_awt_dnd_DragSourceDropEvent$fields_struct	_jc_java_awt_dnd_DragSourceDropEvent$fields_struct;
typedef const struct _jc_java_awt_dnd_DragSourceDropEvent$vmethods	_jc_java_awt_dnd_DragSourceDropEvent$vmethods;
typedef const struct _jc_java_awt_dnd_DragSourceDropEvent$vtable	_jc_java_awt_dnd_DragSourceDropEvent$vtable;
typedef const struct _jc_java_awt_dnd_DragSourceDropEvent$vtype	_jc_java_awt_dnd_DragSourceDropEvent$vtype;

// Class fields structure
struct _jc_java_awt_dnd_DragSourceDropEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_dnd_DragSourceDropEvent$fields_struct _jc_java_awt_dnd_DragSourceDropEvent$class_fields;

// Constructors
extern void _jc_java_awt_dnd_DragSourceDropEvent$method$_init$64d9ad50fc3f446f(_jc_env *, struct _jc_java_awt_dnd_DragSourceDropEvent$object *, struct _jc_java_awt_dnd_DragSourceContext$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_dnd_DragSourceDropEvent$method$_init$1116487a21365ea1(_jc_env *, struct _jc_java_awt_dnd_DragSourceDropEvent$object *, struct _jc_java_awt_dnd_DragSourceContext$object *, jint, jboolean) _JC_JCNI_ATTR;
extern void _jc_java_awt_dnd_DragSourceDropEvent$method$_init$f32e111d49289dbc(_jc_env *, struct _jc_java_awt_dnd_DragSourceDropEvent$object *, struct _jc_java_awt_dnd_DragSourceContext$object *, jint, jboolean, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_awt_dnd_DragSourceDropEvent$method$getDropAction$edda4aeecf125b6a(_jc_env *, struct _jc_java_awt_dnd_DragSourceDropEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_dnd_DragSourceDropEvent$method$getDropSuccess$dfbe197d0d99e605(_jc_env *, struct _jc_java_awt_dnd_DragSourceDropEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DragSourceDropEvent$method_info$getDropAction$edda4aeecf125b6a;
extern _jc_method _jc_java_awt_dnd_DragSourceDropEvent$method_info$getDropSuccess$dfbe197d0d99e605;

// Virtual methods structure
struct _jc_java_awt_dnd_DragSourceDropEvent$vmethods {
	jint	(*getDropAction$edda4aeecf125b6a)(_jc_env *, struct _jc_java_awt_dnd_DragSourceDropEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*getDropSuccess$dfbe197d0d99e605)(_jc_env *, struct _jc_java_awt_dnd_DragSourceDropEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_dnd_DragSourceDropEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_dnd_DragSourceEvent$vmethods	java_awt_dnd_DragSourceEvent;
	_jc_java_awt_dnd_DragSourceDropEvent$vmethods	java_awt_dnd_DragSourceDropEvent;
};

// Vtype
struct _jc_java_awt_dnd_DragSourceDropEvent$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DragSourceDropEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DragSourceDropEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DragSourceDropEvent$refs {
    _jc_java_awt_dnd_DragSourceDropEvent$sub_refs	java_awt_dnd_DragSourceDropEvent;
    _jc_java_awt_dnd_DragSourceEvent$sub_refs	java_awt_dnd_DragSourceEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DragSourceDropEvent$sub_nonrefs {
	jint	dropAction;
	jboolean	dropSuccess;
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DragSourceDropEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_dnd_DragSourceEvent$sub_nonrefs	java_awt_dnd_DragSourceEvent;
    _jc_java_awt_dnd_DragSourceDropEvent$sub_nonrefs	java_awt_dnd_DragSourceDropEvent;
};

// Object instance structure
struct _jc_java_awt_dnd_DragSourceDropEvent$object {
	_jc_java_awt_dnd_DragSourceDropEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DragSourceDropEvent$vtype	*vtype;
	_jc_java_awt_dnd_DragSourceDropEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DragSourceDropEvent$vtype _jc_java_awt_dnd_DragSourceDropEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DragSourceDropEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DragSourceDropEvent$class_object;

#endif	/* _JC_java_awt_dnd_DragSourceDropEvent_H_ */
